import React, { Fragment } from "react";
import { StyleSheet, css } from "aphrodite";
import Link from "next/link";

import ComponentWrapper from "~/components/ComponentWrapper";
import colors from "~/config/themes/colors";

class TOS extends React.Component {
  render() {
    return (
      <div className={css(styles.page)}>
        <ComponentWrapper>
          <h1>ResearchHub User Agreement</h1>
          <p className={css(styles.paragraph)}>
            <strong>
              ResearchHub powers hundreds of thousands of distinct online
              communities.
            </strong>
          </p>
          <p className={css(styles.paragraph)}>
            <strong>
              This User Agreement and your conduct make that possible.
            </strong>
          </p>
          <p className={css(styles.paragraph)}>
            This ResearchHub User Agreement (the "<strong>Terms</strong>")
            applies to your access to and use of the websites, mobile apps,
            widgets, and other online products and services (collectively, the "
            <strong>Services</strong>") provided by ResearchHub, Inc. ("
            <strong>ResearchHub</strong>," "<strong>we</strong>," or "
            <strong>us</strong>"). By participating in the ResearchHub Services
            (for example through posting content, reviewing or commenting on
            content, or acting as a moderator) you will have the opportunity to
            earn native ResearchCoin tokens (“[<strong>ResearchCoins]</strong>
            ”), as more fully described below and on the Services. The
            ResearchHub website includes additional policies and requirements
            regarding each of the foregoing, including processes and technical
            requirements for participating in the Services, policies regarding
            how to earn ResearchCoins, our Content Policy (as further defined
            below), and related policies (the “
            <strong>ResearchHub Program Requirements</strong>”), each of which
            are incorporated into and made part of these Terms.{" "}
          </p>
          <p className={css(styles.paragraph)}>
            By accessing or using our Services, you agree to be bound by these
            Terms. If you do not agree to these Terms, you may not access or use
            our Services. If you are accessing and using the Services on behalf
            of a company (such as your employer) or other legal entity, you
            represent and warrant that you have the authority to bind that
            company or other legal entity to these Terms. In that case, “you”
            and “your” will refer to that company or other legal entity.
          </p>
          <p className={css(styles.paragraph)}>
            Please take a look at ResearchHub’s Privacy Policy too—it explains
            how we collect, use, and share information about you when you access
            or use our Services.
          </p>
          <p className={css(styles.paragraph)}>
            <strong>
              IMPORTANT NOTICE REGARDING ARBITRATION: WHEN YOU AGREE TO THESE
              TERMS YOU ARE AGREEING (WITH LIMITED EXCEPTION) TO RESOLVE ANY
              DISPUTE BETWEEN YOU AND US THROUGH BINDING, INDIVIDUAL ARBITRATION
              RATHER THAN IN COURT. PLEASE REVIEW CAREFULLY SECTION 13 (DISPUTE
              RESOLUTION) BELOW FOR DETAILS REGARDING ARBITRATION (INCLUDING THE
              PROCEDURE TO OPT OUT OF ARBITRATION).
            </strong>
          </p>
          <h2>
            <strong>1. Access to the Services</strong>
          </h2>
          <p className={css(styles.paragraph, styles.indent)}>
            1.1 Eligibility. You may access and use the Services only if you are
            a legal entity or individual 18 years or older and capable of
            forming a binding contract and are not barred from participating
            under applicable law. You may not establish an account or
            participate if you are resident in or a national of any country or
            region that is subject to a general trade embargo administered by
            the United States Office of Foreign Asset Controls, including Iran,
            Syria, Cuba, North Korea, or the Crimea Region of Ukraine.
            Additionally, if you are in the European Economic Area, you must be
            over the age required by the laws of your country to create an
            account or otherwise use the Services, or we need to have received
            verifiable consent from your parent or legal guardian. You cannot
            use the Services if you are not able to form legally binding
            contracts (for example, if you are under 18 years old); if you are
            temporarily or indefinitely suspended from using ResearchHub's
            websites, mobile apps, and other online products and services; or
            are a person with whom transactions are prohibited under applicable
            economic or trade sanctions.
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            1.2 Registration and Accounts. In order to access and use certain of
            the Services, you will have to register and create an account (your
            “<strong>Account</strong>”). Upon registration you will receive a
            user identification, keys, and/or other credentials that will be
            used to associate you to the Services (collectively, “
            <strong>Credentials</strong>”). You are solely responsible for the
            security of your Credentials, are required to take appropriate
            measures to safeguard your Credentials, and will be responsible for
            any unauthorized access to or use of your Credentials. You will be
            solely responsible for all acts or omissions of any person using the
            Services or your Account with your Credentials. All transactions
            generated by use of your Credentials or originating from your
            Account will be deemed to be authorized by you. You will promptly
            notify ResearchHub if you discover or suspect that someone has
            accessed your Account without your permission. We recommend that you
            use a strong password that is used only with the Services. You will
            not license, sell, or transfer your Account without our prior
            written approval.
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            1.3 Accuracy of Account Information. You represent and warrant that
            the information you provide for your account is accurate, complete,
            and up-to-date. You agree to update such information to keep it
            accurate and complete throughout your access to and use of the
            Services. Failure to provide or keep your information accurate,
            complete, and up-to-date may result in suspension or termination of
            your Account.
          </p>
          <h2>
            <strong>2. The Services</strong>
          </h2>
          <p className={css(styles.paragraph)}>2.1 ResearchCoins</p>
          <p>
            ResearchCoins are a virtual item controlled by you and maintained on
            the Ethereum blockchain. ResearchCoin totals and transactions are
            stored as standard ERC-20 tokens publicly and permanently on the
            Ethereum blockchain. ResearchCoins are distributed on a monthly
            basis and are linked publicly to your username. The community can
            modify the distribution of ResearchCoins from the default
            distribution before the ResearchCoins are written into the Ethereum
            blockchain. You have six months after distribution to claim your
            ResearchCoins before the claim expires.
          </p>
          <p className={css(styles.paragraph)}>
            ResearchCoins have no monetary value (i.e., are not a cash account
            or equivalent), cannot be sold to other users, and cannot be
            exchanged for cash or for any other goods and services outside of
            ResearchHub’s virtual goods or services. ResearchHub does not
            guarantee that ResearchCoins, or any virtual goods or services that
            ResearchCoins provide access to or use of (e.g., Promotion, and
            Grants), will continually be offered or will be available for any
            particular length of time, or that they will have or retain any
            value.
          </p>
          <p className={css(styles.paragraph)}>
            The Services will allocate ResearchCoin to your account based in
            part on a reputation score determined in accordance with the
            algorithm described in the ResearchHub Program Requirements. Your
            reputation score will be based upon a number of factors, as
            described in the ResearchHub Program Requirements. We reserve the
            right to change the algorithm for calculating reputation scores at
            any time.
          </p>
          <p className={css(styles.paragraph)}>
            YOU ACKNOWLEDGE AND AGREE THAT YOU MAY NOT RECEIVE ANY ResearchCoin
            REWARDS FROM RESEARCH HUB OR OTHERWISE IN CONNECTION WITH YOUR
            PARTRICIPARTION IN OR USE OF THE SERVICES. RESEARCHHUB DOES NOT
            GUARANTEE ANY ResearchCoin REWARDS WHATSOEVER, REGARDLESS OF THE
            AMOUNT OF TIME OR EFFORT INVOLVED IN YOUR PARTICIPATION IN THE
            SERVICES OR THE VALUE OF YOUR CONTENT. PARTICIPATION IN THE
            RESEARCHUB SERVICES AND POSTING YOUR CONTENT IS DONE AT YOUR SOLE
            DISCRETION.{" "}
          </p>
          <p className={css(styles.paragraph)}>2.2 Transactions</p>
          <p className={css(styles.paragraph)}>
            You control your ResearchCoins and you can transfer them to other
            ResearchHub accounts or any Ethereum blockchain address. We have no
            control over the Ethereum blockchain and cannot ensure any
            transaction details you submit via the Services will be completed.
            Once transaction details have been submitted to the Ethereum
            blockchain via the Services, we cannot assist you to cancel,
            reverse, or otherwise modify your transaction details. We strongly
            encourage you to review your transaction details carefully before
            submitting them.
          </p>
          <p className={css(styles.paragraph)}>2.3 Fees</p>
          <p className={css(styles.paragraph)}>
            We do not currently charge fees for ResearchCoin transactions, but
            we reserve the right to do so in the future. Other Ethereum wallets
            may charge for Ethereum network costs associated with ResearchCoins
            transactions.
          </p>
          <h2>
            <strong>3. Your Use of the Services</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            ResearchHub grants you a personal, non-transferable, non-exclusive,
            revocable, limited license to use and access the Services solely as
            permitted by these Terms. We reserve all rights not expressly
            granted to you by these Terms.
          </p>
          <p className={css(styles.paragraph)}>
            Except as permitted through the Services or as otherwise permitted
            by us in writing, your license does not include the right to:
          </p>
          <ul className={css(styles.paragraph)}>
            <li>
              license, sell, transfer, assign, distribute, host, or otherwise
              commercially exploit the Services or Content (as defined below);
            </li>
          </ul>
          <ul className={css(styles.paragraph)}>
            <li>
              modify, prepare derivative works of, disassemble, decompile, or
              reverse engineer any part of the Services or Content; or
            </li>
          </ul>
          <ul className={css(styles.paragraph)}>
            <li>
              access the Services or Content in order to build a similar or
              competitive website, product, or service.
            </li>
          </ul>
          <p className={css(styles.paragraph)}>
            We reserve the right to modify, suspend, or discontinue the Services
            (in whole or in part) at any time, with or without notice to you.
            Any future release, update, or other addition to functionality of
            the Services will be subject to these Terms, as they may be updated
            from time to time. You agree that we will not be liable to you or to
            any third party for any modification, suspension, or discontinuation
            of the Services or any part thereof.
          </p>
          <h2>
            <strong>4. Your Content</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            The Services may contain information, text, links, graphics, photos,
            videos, or other materials (“<strong>Content</strong>”), including
            Content created with or submitted to the Services by you or through
            your Account (“<strong>Your Content</strong>”). We take no
            responsibility for and we do not expressly or implicitly endorse any
            of Your Content or Content posted by other users of the Services.
          </p>
          <p className={css(styles.paragraph)}>
            By submitting Your Content to the Services, you represent and
            warrant that you have all rights, power, and authority necessary to
            grant the rights to Your Content contained within these Terms.
            Because you alone are responsible for Your Content, you may expose
            yourself to liability if you post or share Content without all
            necessary rights.
          </p>
          <p className={css(styles.paragraph)}>
            You retain any ownership rights you have in Your Content, but you
            agree that all Content that you upload or post to the Services will
            be licensed by you to all users of the Services under the terms and
            conditions of the Creative Commons Attribution License (CC BY 4.0).
            This license allows anyone to reuse the content for any purpose, as
            long as attribution is provided. We consider a hyperlink or URL back
            to the source page on the ResearchHub Services sufficient
            attribution. You agree to include in Your Content an express notice
            that Your Content is licensed under the CC BY 4.0 license.
          </p>
          <p className={css(styles.paragraph)}>
            In addition to the rights granted under the CC BY 4.0 license, you
            grant to ResearchHub the following license with respect to Your
            Content:
          </p>
          <p className={css(styles.paragraph)}>
            When Your Content is created with or submitted to the Services, you
            grant us a worldwide, royalty-free, perpetual, irrevocable,
            non-exclusive, transferable, and sublicensable license to use, copy,
            modify, adapt, prepare derivative works from, distribute, perform,
            and display Your Content and any name, username, voice, or likeness
            provided in connection with Your Content in all media formats and
            channels now known or later developed. This license includes the
            right for us to make Your Content available for syndication,
            broadcast, distribution, or publication by other companies,
            organizations, or individuals who partner with ResearchHub. You also
            agree that we may remove metadata associated with Your Content, and
            you irrevocably waive any claims and assertions of moral rights or
            attribution with respect to Your Content.
          </p>
          <p className={css(styles.paragraph)}>
            Any ideas, suggestions, and feedback about ResearchHub or our
            Services that you provide to us are entirely voluntary, and you
            agree that ResearchHub may use such ideas, suggestions, and feedback
            without compensation or obligation to you.
          </p>
          <p className={css(styles.paragraph)}>
            Although we have no obligation to screen, edit, or monitor Your
            Content, we may, in our sole discretion, delete or remove Your
            Content at any time and for any reason, including for a violation of
            these Terms, a violation of the Policy posted on our website, as may
            be amended from time to time (the “Content Policy”), or if you
            otherwise create liability for us.{" "}
          </p>
          <h2>
            <strong>
              5. Third-Party Content, Advertisements and Promotions
            </strong>
          </h2>
          <p className={css(styles.paragraph)}>
            The Services may contain links to third-party websites, content,
            products, or services, which may be posted by advertisers, our
            affiliates, our partners, or other users (“
            <strong>Third-Party Content</strong>”). Third-Party Content is not
            under our control, and we are not responsible for any such
            Third-Party Content. Your use of Third-Party Content is at your own
            risk and you should make any investigation you feel necessary before
            proceeding with any transaction in connection with such Third-Party
            Content.
          </p>
          <p className={css(styles.paragraph)}>
            The Services may also contain sponsored Third-Party Content or
            advertisements. The type, degree, and targeting of advertisements
            are subject to change, and you acknowledge and agree that we may
            place advertisements in connection with the display of any Content
            or information on the Services, including Your Content.
          </p>
          <p className={css(styles.paragraph)}>
            If you choose to use the Services to conduct a promotion, including
            a contest or sweepstakes, you alone are responsible for conducting
            the promotion in compliance with all applicable laws and
            regulations. The terms of your promotion must specifically state
            that the promotion is not sponsored by, endorsed by, or associated
            with ResearchHub and the rules for your promotion must require each
            entrant or participant to release ResearchHub from any liability
            related to the promotion.
          </p>
          <h2>
            <strong>6. Things You Cannot Do</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            When accessing or using the Services, you must respect others and
            their rights, including by following these Terms and the Content
            Policy, so that we all may continue to use and enjoy the Services.
            We support the responsible reporting of security vulnerabilities. To
            report a security issue, please send an email to{" "}
            <a
              href="mailto:hello@researchhub.com"
              target="_blank"
              rel="noreferrer noopener"
            >
              hello@researchhub.com
            </a>
            .
          </p>
          <p className={css(styles.paragraph)}>
            When accessing or using our Services, you will not:
          </p>
          <ul>
            <li>
              Create or submit Content that violates our Content Policy or
              attempt to circumvent any content-filtering techniques we use;
            </li>
          </ul>
          <ul>
            <li>
              Use the Services to violate applicable law or infringe any person
              or entity's intellectual property or any other proprietary rights;
            </li>
          </ul>
          <ul>
            <li>
              Attempt to gain unauthorized access to another user’s Account or
              to the Services (or to other computer systems or networks
              connected to or used together with the Services);
            </li>
          </ul>
          <ul>
            <li>
              Upload, transmit, or distribute to or through the Services any
              computer viruses, worms, or other software intended to interfere
              with the intended operation of a computer system or data;
            </li>
          </ul>
          <ul>
            <li>
              Use the Services to harvest, collect, gather or assemble
              information or data regarding the Services or users of the
              Services except as permitted in these Terms or in a separate
              agreement with ResearchHub;
            </li>
          </ul>
          <ul>
            <li>
              Use the Services in any manner that could interfere with, disrupt,
              negatively affect, or inhibit other users from fully enjoying the
              Services or that could damage, disable, overburden, or impair the
              functioning of the Services in any manner;
            </li>
          </ul>
          <ul>
            <li>
              Intentionally negate any user's actions to delete or edit their
              Content on the Services; or
            </li>
          </ul>
          <ul>
            <li>
              Access, query, or search the Services with any automated system,
              other than through our published interfaces and pursuant to their
              applicable terms. However, we conditionally grant permission to
              crawl the Services for the sole purpose of and solely to the
              extent necessary for creating publicly available searchable
              indices of the materials subject to the parameters set forth in
              our robots.txt file.
            </li>
          </ul>
          <h2>
            <strong>7. Moderators</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            Moderating a Hub is an unofficial, voluntary position that may be
            available to users of the Services. We are not responsible for
            actions taken by the moderators. We recognize that moderation can
            take some work, so we may change the features or abilities
            associated with moderating from time to time without prior notice.
            We reserve the right to revoke or limit a user’s ability to moderate
            at any time and for any reason or no reason, including for a breach
            of these Terms.
          </p>
          <p className={css(styles.paragraph)}>
            If you choose to moderate a Hub:
          </p>
          <ul>
            <li>
              You agree that when you receive reports related to your community,
              that you will take action to moderate by removing content and/or
              escalating to the admins for review;
            </li>
          </ul>
          <ul>
            <li>
              You may not represent that you are authorized to act on behalf of
              ResearchHub, Inc.;
            </li>
          </ul>
          <ul>
            <li>
              You may not enter into any agreement with a third party on behalf
              of ResearchHub, or any subreddits that you moderate, without our
              written approval;
            </li>
          </ul>
          <ul>
            <li>
              You may not perform moderation actions in return for any form of
              compensation or favor from third parties;
            </li>
          </ul>
          <ul>
            <li>
              If you have access to non-public information as a result of
              moderating a subreddit, you will use such information only in
              connection with your performance as a moderator; and
            </li>
          </ul>

          <p className={css(styles.paragraph)}>
            ResearchHub reserves the right, but has no obligation, to overturn
            any action or decision of a moderator if ResearchHub believes that
            such action or decision is not in the interest of ResearchHub or the
            ResearchHub community.
          </p>
          <h2>
            <strong>8. Copyright, the DMCA &amp; Takedowns</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            ResearchHub respects the intellectual property of others and
            requires that users of our Services do the same. We have a policy
            that includes the removal of any infringing materials from the
            Services and for the termination, in appropriate circumstances, of
            users of our Services who are repeat infringers. If you believe that
            anything on our Services infringes a copyright that you own or
            control, you may notify ResearchHub’s Designated Agent by filling
            out our DMCA Report Form or by contacting:
          </p>
          <p className={css(styles.paragraph)}>Copyright Agent</p>
          <p className={css(styles.paragraph)}>
            <a
              href="mailto:hello@researchhub.com"
              target="_blank"
              rel="noreferrer noopener"
            >
              hello@researchhub.com
            </a>
          </p>
          <p className={css(styles.paragraph)}>
            Also, please note that if you knowingly misrepresent that any
            activity or material on our Service is infringing, you may be liable
            to ResearchHub for certain costs and damages.
          </p>
          <p className={css(styles.paragraph)}>
            If we remove Your Content in response to a copyright or trademark
            notice, we will notify you.. If you believe Your Content was wrongly
            removed due to a mistake or misidentification, you can send a
            counter notification to our Copyright Agent (contact information
            provided above). Please see 17 U.S.C. §512(g)(3) for the
            requirements of a proper counter notification.
          </p>
          <h2>
            <strong>9. Indemnity</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            Except to the extent prohibited by law, you agree to defend,
            indemnify, and hold us, our licensors, our third party service
            providers and our officers, employees, licensors, and agents (the “
            <strong>ResearchHub Entities</strong>”) harmless, including costs
            and attorneys’ fees, from any claim or demand made by any third
            party due to or arising out of (a) your use of the Services, (b)
            your violation of these Terms, (c) your violation of applicable laws
            or regulations, or (d) Your Content. We reserve the right to control
            the defense of any matter for which you are required to indemnify
            us, and you agree to cooperate with our defense of these claims.
          </p>
          <h2>
            <strong>10. Disclaimers</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            THE SERVICES ARE PROVIDED "AS IS" AND "AS AVAILABLE" WITHOUT
            WARRANTIES OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING, BUT
            NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
            PARTICULAR PURPOSE, AND NON-INFRINGEMENT. RESEARCHHUB, ITS
            LICENSORS, AND ITS THIRD PARTY SERVICE PROVIDERS DO NOT WARRANT THAT
            THE SERVICES ARE ACCURATE, COMPLETE, RELIABLE, CURRENT, OR ERROR
            FREE. RESEARCHHUB DOES NOT CONTROL, ENDORSE, OR TAKE RESPONSIBILITY
            FOR ANY CONTENT AVAILABLE ON OR LINKED TO THE SERVICES OR THE
            ACTIONS OF ANY THIRD PARTY OR USER, INCLUDING MODERATORS. WHILE
            RESEARCHHUB ATTEMPTS TO MAKE YOUR ACCESS TO AND USE OF OUR SERVICES
            SAFE, WE DO NOT REPRESENT OR WARRANT THAT OUR SERVICES OR SERVERS
            ARE FREE OF VIRUSES OR OTHER HARMFUL COMPONENTS.
          </p>
          <p className={css(styles.paragraph)}>
            YOU ARE SOLELY RESPONSIBLE FOR THE PROPER CREATION, STORAGE, BACKUP,
            TRANSFER AND OTHER USE OF YOUR RESEARCHCOIN WALLET AND ANY OTHER
            WALLETS OR ACCOUNTS YOU MAY HAVE OR ESTABLISH ON THE ETHEREUM
            NETWORK. YOU ASSUME FULL RESPONSIBILITY AND LIABILITY FOR ANY LOSSES
            FROM ANY INTENTIONAL OR UNINTENTIONAL MISUSE OF YOUR RESEARCHCOIN
            WALLET, INCLUDING ANY LOSS RESULTING FROM DESIGNATING A
            NON-COMPLIANT WALLET FOR THE RECEIPT OF TOKENS, DEPOSITING OR
            STAKING TOKENS TO A NON-COMPLIANT WALLET OR NON-EXISTENT WALLET, OR
            ERRORS OR TYPOS IN ANY WALLET ADDRESSES THAT YOU PROVIDE TO ANYONE.
            WE WILL NOT BE LIABLE TO YOU FOR ANY LOSSES ARISING OUT OF OR IN
            CONNECTION WITH (I) ACTS OR OMISSIONS BY YOU, (II) SOFTWARE BUGS,
            ERRORS, OR DOWNTIME IN THE ETHEREUM NETWORK OR THE BLOCKCHAIN
            NETWORK UNDERLYING ResearchCoinS, (III) FORKS TO THE ETHEREUM
            NETWORK OR ResearchCoinS, OR (IV) HACKS OR CYBERSECURITY BREACHES BY
            A THIRD PARTY.
          </p>
          <h2>
            <strong>11. Limitation of Liability</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            IN NO EVENT AND UNDER NO THEORY OF LIABILITY, INCLUDING CONTRACT,
            TORT, NEGLIGENCE, STRICT LIABILITY, WARRANTY, OR OTHERWISE, WILL THE
            RESEARCHHUB ENTITIES BE LIABLE TO YOU FOR ANY INDIRECT,
            CONSEQUENTIAL, EXEMPLARY, INCIDENTAL, SPECIAL, OR PUNITIVE DAMAGES,
            OR LOST PROFITS ARISING FROM OR RELATING TO THESE TERMS OR THE
            SERVICES, INCLUDING THOSE ARISING FROM OR RELATING TO CONTENT MADE
            AVAILABLE ON THE SERVICES THAT IS ALLEGED TO BE DEFAMATORY,
            OFFENSIVE, OR ILLEGAL. ACCESS TO, AND USE OF, THE SERVICES IS AT
            YOUR OWN DISCRETION AND RISK, AND YOU WILL BE SOLELY RESPONSIBLE FOR
            ANY DAMAGE TO YOUR DEVICE OR COMPUTER SYSTEM, OR LOSS OF DATA
            RESULTING THEREFROM. IN NO EVENT WILL THE AGGREGATE LIABILITY OF THE
            RESEARCHHUB ENTITIES EXCEED THE GREATER OF ONE HUNDRED U.S. DOLLARS
            ($100) OR ANY AMOUNT YOU PAID RESEARCHHUB IN THE PREVIOUS SIX MONTHS
            FOR THE SERVICES GIVING RISE TO THE CLAIM. THE LIMITATIONS OF THIS
            SECTION WILL APPLY TO ANY THEORY OF LIABILITY, INCLUDING THOSE BASED
            ON WARRANTY, CONTRACT, STATUTE, TORT (INCLUDING NEGLIGENCE) OR
            OTHERWISE, AND EVEN IF THE RESEARCHHUB ENTITIES HAVE BEEN ADVISED OF
            THE POSSIBILITY OF ANY SUCH DAMAGE, AND EVEN IF ANY REMEDY SET FORTH
            HEREIN IS FOUND TO HAVE FAILED ITS ESSENTIAL PURPOSE. THE FOREGOING
            LIMITATION OF LIABILITY WILL APPLY TO THE FULLEST EXTENT PERMITTED
            BY LAW IN THE APPLICABLE JURISDICTION.
          </p>
          <h2>
            <strong>12. Governing Law and Venue; Dispute Resolution</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            We want you to enjoy ResearchHub, so if you have an issue or
            dispute, you agree to raise it and try to resolve it with us
            informally. You can contact us with feedback and concerns here or by
            emailing us at{" "}
            <a
              href="mailto:hello@researchhub.com"
              target="_blank"
              rel="noreferrer noopener"
            >
              hello@researchhub.com
            </a>
            .
          </p>
          <p className={css(styles.paragraph)}>
            Except for the government entities listed below: any claims arising
            out of or relating to these Terms or the Services will be governed
            by the laws of California, other than its conflict of laws rules.
            Except as set forth below with respect to arbitration, all disputes
            related to these Terms or the Services will be brought solely in the
            federal or state courts located in San Francisco, California; and
            you consent to personal jurisdiction in these courts.
          </p>
          <h3 className={css(styles.paragraph)}>
            <strong>Dispute Resolution:</strong>
          </h3>
          <p className={css(styles.paragraph, styles.indent)}>
            (a) Mandatory Arbitration of Disputes. We each agree that any
            dispute, claim or controversy arising out of or relating to these
            Terms or the breach, termination, enforcement, interpretation or
            validity thereof or the use of the Services or Content
            (collectively, “<strong>Disputes</strong>”) will be resolved solely
            by binding, individual arbitration and not in a class,
            representative or consolidated action or proceeding. You and we
            agree that the U.S. Federal Arbitration Act governs the
            interpretation and enforcement of these Terms, and that you and we
            are each waiving the right to a trial by jury or to participate in a
            class action. This arbitration provision shall survive termination
            of these Terms.{" "}
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            (b) Exceptions and Opt-out. As limited exceptions to the above: (i)
            you may seek to resolve a Dispute in small claims court if it
            qualifies; and (ii) we each retain the right to seek injunctive or
            other equitable relief from a court to prevent (or enjoin) the
            infringement or misappropriation of our intellectual property
            rights. In addition, you will retain the right to opt out of
            arbitration entirely and litigate any Dispute if you provide us with
            written notice of your desire to do so by email at{" "}
            <a
              href="mailto:hi@videocoin.io"
              target="_blank"
              rel="noreferrer noopener"
            >
              hi@videocoin.io
            </a>{" "}
            or by regular mail at [postal address] within thirty (30) days
            following the date you first agree to these Terms.
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            (c) Conducting Arbitration and Arbitration Rules. The arbitration
            will be conducted by the American Arbitration Association (“
            <strong>AAA</strong>”) under its Consumer Arbitration Rules (the
            “AAA Rules”) then in effect, except as modified by these Terms. The
            AAA Rules are available at{" "}
            <a
              href="http://www.adr.org"
              target="_blank"
              rel="noreferrer noopener"
            >
              www.adr.org
            </a>{" "}
            or by calling 1-800-778-7879. A party who wishes to start
            arbitration must submit a written Demand for Arbitration to AAA and
            give notice to the other party as specified in the AAA Rules. The
            AAA provides a form Demand for Arbitration at{" "}
            <a
              href="http://www.adr.org"
              target="_blank"
              rel="noreferrer noopener"
            >
              www.adr.org
            </a>
            .{" "}
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            If your claim is for U.S. $10,000 or less, you may choose whether
            the arbitration will be conducted solely on the basis of documents
            submitted to the arbitrator, through a telephonic or
            video-conference hearing, or by an in-person hearing as established
            by the AAA Rules. If your claim exceeds U.S. $10,000, the right to a
            hearing will be determined by the AAA Rules. Any arbitration
            hearings will take place in the county (or parish) where you live,
            unless we both agree to a different location. The parties agree that
            the arbitrator shall have exclusive authority to decide all issues
            relating to the interpretation, applicability, enforceability and
            scope of this arbitration agreement.
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            (d) Arbitration Costs. Payment of all filing, administration and
            arbitrator fees will be governed by the AAA Rules. We’ll pay for all
            filing, administration and arbitrator fees and expenses if your
            Dispute is for less than $10,000, unless the arbitrator finds your
            Dispute frivolous. If we prevail in arbitration we’ll pay all of our
            attorneys’ fees and costs and won’t seek to recover them from you.
            If you prevail in arbitration you will be entitled to an award of
            attorneys’ fees and expenses to the extent provided under applicable
            law.
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            (e) Class Action Waiver. YOU AND WE AGREE THAT EACH MAY BRING CLAIMS
            AGAINST THE OTHER ONLY IN YOUR OR ITS INDIVIDUAL CAPACITY, AND NOT
            AS A PLAINTIFF OR CLASS MEMBER IN ANY PURPORTED CLASS OR
            REPRESENTATIVE PROCEEDING. Further, if the parties’ dispute is
            resolved through arbitration, the arbitrator may not consolidate
            another person's claims with your claims, and may not otherwise
            preside over any form of a representative or class proceeding. If
            this specific provision is found to be unenforceable, then the
            entirety of this Dispute Resolution section shall be null and void.
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            (f) Effect of Changes on Arbitration. Notwithstanding the provisions
            of Section 14 (Changes to Terms), if we change any of the terms of
            this Section 13 (Dispute Resolution) after the date you first
            accepted these Terms (or accepted any subsequent changes to these
            Terms), you may reject any such change by sending us written notice
            (including by email to{" "}
            <a
              href="mailto:disputes@videocoin.io"
              target="_blank"
              rel="noreferrer noopener"
            >
              disputes@videocoin.io
            </a>
            ) within 30 days of the date such change became effective, as
            indicated in the “Last Updated” date above or in the date of our
            email to you notifying you of such change. By rejecting any change,
            you are agreeing that you will arbitrate any Dispute between you and
            us in accordance with the terms of this Section 13 (Dispute
            Resolution) as of the date you first accepted these Terms (or
            accepted any subsequent changes to these Terms).
          </p>
          <p className={css(styles.paragraph, styles.indent)}>
            (g) Severability. With the exception of any of the provisions in
            sub-section (e) (Class Action Waiver), if an arbitrator or court of
            competent jurisdiction decides that any part of these Terms is
            invalid or unenforceable, the other parts of these Terms will still
            apply.
          </p>
          <p className={css(styles.paragraph)}>
            <strong>Government Entities</strong>
          </p>
          <p className={css(styles.paragraph)}>
            If you are a U.S. city, county, or state government entity, then
            this Section 13 does not apply to you.
          </p>
          <p className={css(styles.paragraph)}>
            If you are a U.S. federal government entity: any claims arising out
            of or relating to these Terms or the Services will be governed by
            the laws of the United States of America without reference to
            conflict of laws. To the extent permitted by federal law, the laws
            of California (other than its conflict of law rules) will apply in
            the absence of applicable federal law. All disputes related to these
            Terms or the Services will be brought solely in the federal or state
            courts located in San Francisco, California.
          </p>
          <h2>
            <strong>13. Changes to these Terms</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            We may make changes to these Terms from time to time. If we make
            changes, we will post the amended Terms to our Services and update
            the Effective Date above. If the changes, in our sole discretion,
            are material, we may also notify you by sending an email to the
            address associated with your Account (if you have chosen to provide
            an email address) or by otherwise providing notice through our
            Services. By continuing to access or use the Services on or after
            the Effective Date of the revised Terms, you agree to be bound by
            the revised Terms. If you do not agree to the revised Terms, you
            must stop accessing and using our Services before the changes become
            effective.
          </p>
          <h2>
            <strong>14. Additional Terms</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            Because we offer a variety of Services, you may be asked to agree to
            additional terms before using a specific product or service offered
            by ResearchHub (“<strong>Additional Terms</strong>”). To the extent
            any Additional Terms conflict with these Terms, the Additional Terms
            govern with respect to your use of the corresponding Service.
          </p>
          <h2>
            <strong>15. Termination</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            You may terminate these Terms at any time and for any reason by
            deleting your Account and discontinuing your use of all Services. If
            you stop using the Services without deactivating your Accounts, your
            Accounts may be deactivated due to prolonged inactivity.
          </p>
          <p className={css(styles.paragraph)}>
            We may suspend or terminate your Accounts, status as a moderator, or
            ability to access or use the Services at any time for any or no
            reason, including for a violation of these Terms or our Content
            Policy.
          </p>
          <p className={css(styles.paragraph)}>
            As stated in these Terms and our Content Policy, you must follow and
            comply with the rules of the ResearchHub platform. Failure to do so
            may result in a temporary or permanent ban from ResearchHub or the
            removal of your posts and comments. In such instances, you might
            lose the benefits of your ResearchCoins. There are no refunds.
          </p>
          <p className={css(styles.paragraph)}>
            The following sections will survive any termination of these Terms
            or of your Accounts: 4 (Your Content), 6 (Things You Cannot Do), 9
            (Indemnity), 10 (Disclaimers), 11 (Limitation of Liability), 12
            (Governing Law and Venue; Dispute Resolution), 15 (Termination), and
            16 (Miscellaneous).
          </p>
          <h2>
            <strong>16. Miscellaneous</strong>
          </h2>
          <p className={css(styles.paragraph)}>
            These Terms, together with any Additional Terms, our Privacy Policy,
            and our Content Policy, constitute the entire agreement between you
            and us regarding your access to and use of the Services. Our failure
            to exercise or enforce any right or provision of these Terms will
            not operate as a waiver of such right or provision. If any provision
            of these Terms is, for any reason, held to be illegal, invalid or
            unenforceable, the rest of the Terms will remain in effect. You may
            not assign or transfer any of your rights or obligations under these
            Terms without our consent. We may freely assign these Terms.
          </p>
          <h3 className={css(styles.paragraph)}>
            <strong>Contact Information</strong>
          </h3>
          <p className={css(styles.paragraph)}>
            <a
              href="mailto:hello@researchhub.com"
              target="_blank"
              rel="noreferrer noopener"
            >
              hello@researchhub.com
            </a>
          </p>
        </ComponentWrapper>
      </div>
    );
  }
}

const styles = StyleSheet.create({
  page: {
    paddingTop: 10,
    paddingBottom: 20,
    maxWidth: "100vw",
    overflow: "hidden",
    lineHeight: 1.6,
  },
  paragraph: {
    marginTop: 7,
    marginBottom: 7,
    fontWeight: 400,
  },
  indent: {
    textIndent: 50,
  },
});

export default TOS;
